Indication

Enum Indication 

pub enum Indication {
    Transaction(TransactionID),
    EoFSent(TransactionID),
    EoFRecv(TransactionID),
    Finished(FinishedIndication),
    MetadataRecv(MetadataRecvIndication),
    FileSegmentRecv(FileSegmentIndication),
    Report(Report),
}
Indications how the Daemon and Transactions relay information back to the User application. Indications are issued at necessary points in each Transaction’s lifetime.

Variants



Transaction(TransactionID)

A new transaction has been initiated as a result of a PutRequest



EoFSent(TransactionID)

End of File has been Sent



EoFRecv(TransactionID)

End of File PDU has been received



Finished(FinishedIndication)

A running transaction has reached the Finished state. Receipt of this indications starts and post transaction actions.



MetadataRecv(MetadataRecvIndication)

Metadata has been received for a Receive Transaction



FileSegmentRecv(FileSegmentIndication)

A new file segment has been received



Report(Report)

Last known status for the given transaction