pub struct Segments(/* private fields */);Expand description
Holds a list of disjunctive [start, end) segments covering the received file
Implementations
Sourceimpl Segments
impl Segments
pub fn new() -> Self
pub fn is_empty(&self) -> bool
Sourcepub fn end(&self) -> Option<u64>
pub fn end(&self) -> Option<u64>
return the end of the last segment or None if there is no segment
Sourcepub fn is_complete(&self, size: u64) -> bool
pub fn is_complete(&self, size: u64) -> bool
return true if there is only one segment whose end is the given size