pub struct PutRequest {
pub source_filename: Utf8PathBuf,
pub destination_filename: Utf8PathBuf,
pub destination_entity_id: EntityID,
pub transmission_mode: TransmissionMode,
}Expand description
Necessary Configuration for a Put.Request operation
Fields
source_filename: Utf8PathBufBytes of the source filename, can be null if length is 0.
destination_filename: Utf8PathBufBytes of the destination filename, can be null if length is 0.
destination_entity_id: EntityIDDestination ID of the Request
transmission_mode: TransmissionModeWhether to send in acknowledged or unacknowledged mode