pub struct FileDataPDU(pub UnsegmentedFileData);Expand description
A holder for both possible types of File data PDUs.
Tuple Fields
0: UnsegmentedFileDataTrait Implementations
Sourceimpl Clone for FileDataPDU
impl Clone for FileDataPDU
Sourcefn clone(&self) -> FileDataPDU
fn clone(&self) -> FileDataPDU
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FileDataPDU
impl Debug for FileDataPDU
impl Eq for FileDataPDU
Sourceimpl PartialEq for FileDataPDU
impl PartialEq for FileDataPDU
Sourceimpl SegmentEncode for FileDataPDU
impl SegmentEncode for FileDataPDU
type PDUType = FileDataPDU
Sourcefn encoded_len(&self, file_size_flag: FileSizeFlag) -> u16
fn encoded_len(&self, file_size_flag: FileSizeFlag) -> u16
Gets the encoded length must fit in a u16 for PDUs
Sourcefn decode<T: Read>(
buffer: &mut T,
segmentation_flag: SegmentedData,
file_size_flag: FileSizeFlag,
) -> PDUResult<Self::PDUType>
fn decode<T: Read>( buffer: &mut T, segmentation_flag: SegmentedData, file_size_flag: FileSizeFlag, ) -> PDUResult<Self::PDUType>
Attempts to decode a PDU from a byte stream
impl StructuralPartialEq for FileDataPDU