SendTransaction

Struct SendTransaction 

pub struct SendTransaction<T: FileStore> { /* private fields */ }

Implementations

Source

impl<T: FileStore> SendTransaction<T>

pub fn new( config: TransactionConfig, metadata: Metadata, filestore: Arc<T>, indication_tx: Sender<Indication>, ) -> TransactionResult<Self>

Start a new SendTransaction with the given configuration and Filestore Implementation

pub fn handle_timeout(&mut self) -> TransactionResult<()>

pub fn get_status(&self) -> TransactionStatus

pub fn get_mode(&self) -> TransmissionMode

pub fn send_report( &self, sender: Option<Sender<Report>>, ) -> TransactionResult<()>

pub fn id(&self) -> TransactionID

pub fn send_file_segment( &mut self, offset: Option<u64>, length: Option<u16>, permit: Permit<'_, (EntityID, PDU)>, ) -> TransactionResult<()>

Send a segment of size length from position offset in the file. When offset is None, reads from the current cursor location. when length is None uses the maximum length for the receiving Engine. This size is set by the file_size_segment field in the TransactionConfig.

pub fn send_missing_data( &mut self, permit: Permit<'_, (EntityID, PDU)>, ) -> TransactionResult<()>

pub fn send_eof( &mut self, permit: Permit<'_, (EntityID, PDU)>, ) -> TransactionResult<()>

pub fn shutdown(&mut self)

pub fn process_pdu(&mut self, pdu: PDU) -> TransactionResult<()>