pub struct Metadata {
pub source_filename: Utf8PathBuf,
pub destination_filename: Utf8PathBuf,
pub file_size: u64,
pub checksum_type: ChecksumType,
}Fields
source_filename: Utf8PathBufBytes of the source filename, can be null if length is 0.
destination_filename: Utf8PathBufBytes of the destination filename, can be null if length is 0.
file_size: u64The size of the file being transfered in this transaction.
checksum_type: ChecksumTypeFlag to track what kind of Checksum will be used in this transaction.