pub struct TransactionConfig {Show 14 fields
pub source_entity_id: EntityID,
pub destination_entity_id: EntityID,
pub transmission_mode: TransmissionMode,
pub sequence_number: TransactionSeqNum,
pub file_size_flag: FileSizeFlag,
pub fault_handler_override: HashMap<Condition, FaultHandlerAction>,
pub file_size_segment: u16,
pub crc_flag: CRCFlag,
pub segment_metadata_flag: SegmentedData,
pub max_count: u32,
pub inactivity_timeout: i64,
pub nak_timeout: i64,
pub eof_timeout: i64,
pub progress_report_interval_secs: i64,
}Fields
source_entity_id: EntityIDIdentification number of the source (this) entity.
destination_entity_id: EntityIDIdentification number of the destination (remote) entity.
transmission_mode: TransmissionModeCFDP TransmissionMode
sequence_number: TransactionSeqNumThe sequence number in Big Endian Bytes.
file_size_flag: FileSizeFlagFlag to indicate whether or not the file size fits inside a u32
fault_handler_override: HashMap<Condition, FaultHandlerAction>A Mapping of actions to take when each condition is reached. See also Condition and FaultHandlerAction.
file_size_segment: u16The maximum length a file segment sent to Destination can be. u16 will be larger than any possible CCSDS packet size.
crc_flag: CRCFlagFlag indicating whether or not CRCs will be present on the PDUs
segment_metadata_flag: SegmentedDataFlag indicating whether file metadata is included with FileData
max_count: u32Maximum count of timeouts on a timer before a fault is generated.
inactivity_timeout: i64Maximum amount timeof without activity before the inactivity timer increments its count.
nak_timeout: i64Maximum amount timeof without activity before the NAK timer increments its count.
eof_timeout: i64Maximum amount time of without activity before the EOF timer increments its count.
progress_report_interval_secs: i64Interval in secs to send a progress report.