Segments

Struct Segments 

pub struct Segments(/* private fields */);
Holds a list of disjunctive [start, end) segments covering the received file

Implementations

Source

impl Segments

pub fn new() -> Self

pub fn is_empty(&self) -> bool

pub fn len(&self) -> usize

return the number of disjunctive segments

pub fn end(&self) -> Option<u64>

return the end of the last segment or None if there is no segment

pub fn end_or_0(&self) -> u64

return the end of the last segment or 0 if there is no segment

pub fn is_complete(&self, size: u64) -> bool

return true if there is only one segment whose end is the given size

pub fn merge(&mut self, seg: (u64, u64)) -> u64

update the contiguous segment list with the new segment, filling any gap (i.e. unifying segments) if required return the number of new bytes added (e.g. if the new segment overlaps completely existing segments, return 0)

pub fn gaps(&self, start: u64, end: u64) -> Vec<(u64, u64)>

return a list of gaps covering the [start, end) interval