pub struct EntityConfig {Show 14 fields
pub fault_handler_override: HashMap<Condition, FaultHandlerAction>,
pub file_size_segment: u16,
pub default_transaction_max_count: u32,
pub inactivity_timeout: i64,
pub eof_timeout: i64,
pub nak_timeout: i64,
pub crc_flag: CRCFlag,
pub checksum_type: ChecksumType,
pub nak_procedure: NakProcedure,
pub local_entity_id: u16,
pub remote_entity_id: u16,
pub local_server_addr: &'static str,
pub remote_server_addr: &'static str,
pub progress_report_interval_secs: i64,
}Expand description
Configuration parameters for transactions which may change based on the receiving entity.
Fields
fault_handler_override: HashMap<Condition, FaultHandlerAction>Mapping to decide how each fault type should be handled
file_size_segment: u16Maximum file size fragment this entity can receive
default_transaction_max_count: u32inactivity_timeout: i64eof_timeout: i64nak_timeout: i64crc_flag: CRCFlagFlag to determine if the CRC protocol should be used
checksum_type: ChecksumTypeThe default ChecksumType to use for file transfers
nak_procedure: NakProcedurelocal_entity_id: u16remote_entity_id: u16local_server_addr: &'static strremote_server_addr: &'static strprogress_report_interval_secs: i64Trait Implementations
Sourceimpl Clone for EntityConfig
impl Clone for EntityConfig
Sourcefn clone(&self) -> EntityConfig
fn clone(&self) -> EntityConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for EntityConfig
impl RefUnwindSafe for EntityConfig
impl Send for EntityConfig
impl Sync for EntityConfig
impl Unpin for EntityConfig
impl UnsafeUnpin for EntityConfig
impl UnwindSafe for EntityConfig