TransactionConfig

Struct TransactionConfig 

pub struct TransactionConfig {
Show 14 fields pub source_entity_id: EntityID, pub destination_entity_id: EntityID, pub transmission_mode: TransmissionMode, pub sequence_number: TransactionSeqNum, pub file_size_flag: FileSizeFlag, pub fault_handler_override: HashMap<Condition, FaultHandlerAction>, pub file_size_segment: u16, pub crc_flag: CRCFlag, pub segment_metadata_flag: SegmentedData, pub max_count: u32, pub inactivity_timeout: i64, pub nak_timeout: i64, pub eof_timeout: i64, pub progress_report_interval_secs: i64,
}

Fields

source_entity_id: EntityID

Identification number of the source (this) entity.

destination_entity_id: EntityID

Identification number of the destination (remote) entity.

transmission_mode: TransmissionModesequence_number: TransactionSeqNum

The sequence number in Big Endian Bytes.

file_size_flag: FileSizeFlag

Flag to indicate whether or not the file size fits inside a u32

fault_handler_override: HashMap<Condition, FaultHandlerAction>

A Mapping of actions to take when each condition is reached. See also Condition and FaultHandlerAction.

file_size_segment: u16

The maximum length a file segment sent to Destination can be. u16 will be larger than any possible CCSDS packet size.

crc_flag: CRCFlag

Flag indicating whether or not CRCs will be present on the PDUs

segment_metadata_flag: SegmentedData

Flag indicating whether file metadata is included with FileData

max_count: u32

Maximum count of timeouts on a timer before a fault is generated.

inactivity_timeout: i64

Maximum amount timeof without activity before the inactivity timer increments its count.

nak_timeout: i64

Maximum amount timeof without activity before the NAK timer increments its count.

eof_timeout: i64

Maximum amount time of without activity before the EOF timer increments its count.

progress_report_interval_secs: i64

Interval in secs to send a progress report.